# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: app/app_definition.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.core import security_pb2 as flyteidl_dot_core_dot_security__pb2
from flyteidl.core import tasks_pb2 as flyteidl_dot_core_dot_tasks__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from union.internal.validate.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61pp/app_definition.proto\x12\x0c\x63loudidl.app\x1a\x1c\x66lyteidl/core/security.proto\x1a\x19\x66lyteidl/core/tasks.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17validate/validate.proto\"\x88\x01\n\nIdentifier\x12\x19\n\x03org\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x03org\x12!\n\x07project\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x07project\x12\x1f\n\x06\x64omain\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x06\x64omain\x12\x1b\n\x04name\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\"\xd2\x01\n\x04Meta\x12\x32\n\x02id\x18\x01 \x01(\x0b\x32\x18.cloudidl.app.IdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x02id\x12#\n\x08revision\x18\x02 \x01(\x04\x42\x07\xfa\x42\x04\x32\x02(\x00R\x08revision\x12\x36\n\x06labels\x18\x03 \x03(\x0b\x32\x1e.cloudidl.app.Meta.LabelsEntryR\x06labels\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x95\x01\n\x03\x41pp\x12\x38\n\x08metadata\x18\x01 \x01(\x0b\x32\x12.cloudidl.app.MetaB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x08metadata\x12&\n\x04spec\x18\x02 \x01(\x0b\x32\x12.cloudidl.app.SpecR\x04spec\x12,\n\x06status\x18\x03 \x01(\x0b\x32\x14.cloudidl.app.StatusR\x06status\"\xec\x01\n\tCondition\x12L\n\x14last_transition_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x12lastTransitionTime\x12R\n\x11\x64\x65ployment_status\x18\x02 \x01(\x0e\x32%.cloudidl.app.Status.DeploymentStatusR\x10\x64\x65ploymentStatus\x12\x18\n\x07message\x18\x03 \x01(\tR\x07message\x12#\n\x08revision\x18\x04 \x01(\x04\x42\x07\xfa\x42\x04\x32\x02(\x00R\x08revision\"\xc5\x04\n\x06Status\x12)\n\x10\x61ssigned_cluster\x18\x01 \x01(\tR\x0f\x61ssignedCluster\x12\x32\n\x10\x63urrent_replicas\x18\x02 \x01(\rB\x07\xfa\x42\x04*\x02(\x00R\x0f\x63urrentReplicas\x12/\n\x07ingress\x18\x03 \x01(\x0b\x32\x15.cloudidl.app.IngressR\x07ingress\x12\x39\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x42\n\x0flast_updated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\rlastUpdatedAt\x12\x37\n\nconditions\x18\x06 \x03(\x0b\x32\x17.cloudidl.app.ConditionR\nconditions\"\xf2\x01\n\x10\x44\x65ploymentStatus\x12!\n\x1d\x44\x45PLOYMENT_STATUS_UNSPECIFIED\x10\x00\x12 \n\x1c\x44\x45PLOYMENT_STATUS_UNASSIGNED\x10\x01\x12\x1e\n\x1a\x44\x45PLOYMENT_STATUS_ASSIGNED\x10\x02\x12\x1d\n\x19\x44\x45PLOYMENT_STATUS_PENDING\x10\x03\x12\x1d\n\x19\x44\x45PLOYMENT_STATUS_STOPPED\x10\x04\x12\x1d\n\x19\x44\x45PLOYMENT_STATUS_STARTED\x10\x05\x12\x1c\n\x18\x44\x45PLOYMENT_STATUS_FAILED\x10\x06\"\x85\x01\n\x07Ingress\x12*\n\npublic_url\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\x88\x01\x01\xd0\x01\x01R\tpublicUrl\x12(\n\tcname_url\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06\x88\x01\x01\xd0\x01\x01R\x08\x63nameUrl\x12$\n\x07vpc_url\x18\x03 \x01(\tB\x0b\xfa\x42\x08r\x06\x88\x01\x01\xd0\x01\x01R\x06vpcUrl\"\xda\x04\n\x04Spec\x12\x42\n\tcontainer\x18\x01 \x01(\x0b\x32\x18.flyteidl.core.ContainerB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00R\tcontainer\x12\x33\n\x03pod\x18\x02 \x01(\x0b\x32\x15.flyteidl.core.K8sPodB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00R\x03pod\x12\x41\n\x0b\x61utoscaling\x18\x03 \x01(\x0b\x32\x1f.cloudidl.app.AutoscalingConfigR\x0b\x61utoscaling\x12\x35\n\x07ingress\x18\x04 \x01(\x0b\x32\x1b.cloudidl.app.IngressConfigR\x07ingress\x12\x44\n\rdesired_state\x18\x05 \x01(\x0e\x32\x1f.cloudidl.app.Spec.DesiredStateR\x0c\x64\x65siredState\x12!\n\x0c\x63luster_pool\x18\x06 \x01(\tR\x0b\x63lusterPool\x12\x32\n\x06images\x18\x07 \x01(\x0b\x32\x1a.cloudidl.app.ImageSpecSetR\x06images\x12I\n\x10security_context\x18\x08 \x01(\x0b\x32\x1e.flyteidl.core.SecurityContextR\x0fsecurityContext\"c\n\x0c\x44\x65siredState\x12\x1d\n\x19\x44\x45SIRED_STATE_UNSPECIFIED\x10\x00\x12\x19\n\x15\x44\x45SIRED_STATE_STOPPED\x10\x01\x12\x19\n\x15\x44\x45SIRED_STATE_STARTED\x10\x02\x42\x12\n\x0b\x61pp_payload\x12\x03\xf8\x42\x01\"A\n\tImageSpec\x12\x10\n\x03tag\x18\x01 \x01(\tR\x03tag\x12\"\n\rbuild_job_url\x18\x02 \x01(\tR\x0b\x62uildJobUrl\"?\n\x0cImageSpecSet\x12/\n\x06images\x18\x01 \x03(\x0b\x32\x17.cloudidl.app.ImageSpecR\x06images\"]\n\rIngressConfig\x12\x18\n\x07private\x18\x01 \x01(\x08R\x07private\x12\x1c\n\tsubdomain\x18\x02 \x01(\tR\tsubdomain\x12\x14\n\x05\x63name\x18\x03 \x01(\tR\x05\x63name\"\xd1\x01\n\x11\x41utoscalingConfig\x12\x32\n\x08replicas\x18\x01 \x01(\x0b\x32\x16.cloudidl.app.ReplicasR\x08replicas\x12\x44\n\x10scaledown_period\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0fscaledownPeriod\x12\x42\n\x0escaling_metric\x18\x03 \x01(\x0b\x32\x1b.cloudidl.app.ScalingMetricR\rscalingMetric\"\x8a\x01\n\rScalingMetric\x12<\n\x0crequest_rate\x18\x01 \x01(\x0b\x32\x19.cloudidl.app.RequestRateR\x0brequestRate\x12;\n\x0b\x63oncurrency\x18\x02 \x01(\x0b\x32\x19.cloudidl.app.ConcurrencyR\x0b\x63oncurrency\"9\n\x0b\x43oncurrency\x12*\n\x0ctarget_value\x18\x01 \x01(\rB\x07\xfa\x42\x04*\x02 \x00R\x0btargetValue\"9\n\x0bRequestRate\x12*\n\x0ctarget_value\x18\x01 \x01(\rB\x07\xfa\x42\x04*\x02(\x00R\x0btargetValue\"@\n\x08Replicas\x12\x19\n\x03min\x18\x01 \x01(\rB\x07\xfa\x42\x04*\x02(\x00R\x03min\x12\x19\n\x03max\x18\x02 \x01(\rB\x07\xfa\x42\x04*\x02(\x00R\x03maxB\xa1\x01\n\x10\x63om.cloudidl.appB\x12\x41ppDefinitionProtoH\x02P\x01Z&github.com/unionai/cloud/gen/pb-go/app\xa2\x02\x03\x43\x41X\xaa\x02\x0c\x43loudidl.App\xca\x02\x0c\x43loudidl\\App\xe2\x02\x18\x43loudidl\\App\\GPBMetadata\xea\x02\rCloudidl::Appb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'app.app_definition_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\020com.cloudidl.appB\022AppDefinitionProtoH\002P\001Z&github.com/unionai/cloud/gen/pb-go/app\242\002\003CAX\252\002\014Cloudidl.App\312\002\014Cloudidl\\App\342\002\030Cloudidl\\App\\GPBMetadata\352\002\rCloudidl::App'
  _IDENTIFIER.fields_by_name['org']._options = None
  _IDENTIFIER.fields_by_name['org']._serialized_options = b'\372B\004r\002\020\001'
  _IDENTIFIER.fields_by_name['project']._options = None
  _IDENTIFIER.fields_by_name['project']._serialized_options = b'\372B\004r\002\020\001'
  _IDENTIFIER.fields_by_name['domain']._options = None
  _IDENTIFIER.fields_by_name['domain']._serialized_options = b'\372B\004r\002\020\001'
  _IDENTIFIER.fields_by_name['name']._options = None
  _IDENTIFIER.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _META_LABELSENTRY._options = None
  _META_LABELSENTRY._serialized_options = b'8\001'
  _META.fields_by_name['id']._options = None
  _META.fields_by_name['id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _META.fields_by_name['revision']._options = None
  _META.fields_by_name['revision']._serialized_options = b'\372B\0042\002(\000'
  _APP.fields_by_name['metadata']._options = None
  _APP.fields_by_name['metadata']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CONDITION.fields_by_name['revision']._options = None
  _CONDITION.fields_by_name['revision']._serialized_options = b'\372B\0042\002(\000'
  _STATUS.fields_by_name['current_replicas']._options = None
  _STATUS.fields_by_name['current_replicas']._serialized_options = b'\372B\004*\002(\000'
  _INGRESS.fields_by_name['public_url']._options = None
  _INGRESS.fields_by_name['public_url']._serialized_options = b'\372B\010r\006\210\001\001\320\001\001'
  _INGRESS.fields_by_name['cname_url']._options = None
  _INGRESS.fields_by_name['cname_url']._serialized_options = b'\372B\010r\006\210\001\001\320\001\001'
  _INGRESS.fields_by_name['vpc_url']._options = None
  _INGRESS.fields_by_name['vpc_url']._serialized_options = b'\372B\010r\006\210\001\001\320\001\001'
  _SPEC.oneofs_by_name['app_payload']._options = None
  _SPEC.oneofs_by_name['app_payload']._serialized_options = b'\370B\001'
  _SPEC.fields_by_name['container']._options = None
  _SPEC.fields_by_name['container']._serialized_options = b'\372B\005\212\001\002\020\001'
  _SPEC.fields_by_name['pod']._options = None
  _SPEC.fields_by_name['pod']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CONCURRENCY.fields_by_name['target_value']._options = None
  _CONCURRENCY.fields_by_name['target_value']._serialized_options = b'\372B\004*\002 \000'
  _REQUESTRATE.fields_by_name['target_value']._options = None
  _REQUESTRATE.fields_by_name['target_value']._serialized_options = b'\372B\004*\002(\000'
  _REPLICAS.fields_by_name['min']._options = None
  _REPLICAS.fields_by_name['min']._serialized_options = b'\372B\004*\002(\000'
  _REPLICAS.fields_by_name['max']._options = None
  _REPLICAS.fields_by_name['max']._serialized_options = b'\372B\004*\002(\000'
  _globals['_IDENTIFIER']._serialized_start=190
  _globals['_IDENTIFIER']._serialized_end=326
  _globals['_META']._serialized_start=329
  _globals['_META']._serialized_end=539
  _globals['_META_LABELSENTRY']._serialized_start=482
  _globals['_META_LABELSENTRY']._serialized_end=539
  _globals['_APP']._serialized_start=542
  _globals['_APP']._serialized_end=691
  _globals['_CONDITION']._serialized_start=694
  _globals['_CONDITION']._serialized_end=930
  _globals['_STATUS']._serialized_start=933
  _globals['_STATUS']._serialized_end=1514
  _globals['_STATUS_DEPLOYMENTSTATUS']._serialized_start=1272
  _globals['_STATUS_DEPLOYMENTSTATUS']._serialized_end=1514
  _globals['_INGRESS']._serialized_start=1517
  _globals['_INGRESS']._serialized_end=1650
  _globals['_SPEC']._serialized_start=1653
  _globals['_SPEC']._serialized_end=2255
  _globals['_SPEC_DESIREDSTATE']._serialized_start=2136
  _globals['_SPEC_DESIREDSTATE']._serialized_end=2235
  _globals['_IMAGESPEC']._serialized_start=2257
  _globals['_IMAGESPEC']._serialized_end=2322
  _globals['_IMAGESPECSET']._serialized_start=2324
  _globals['_IMAGESPECSET']._serialized_end=2387
  _globals['_INGRESSCONFIG']._serialized_start=2389
  _globals['_INGRESSCONFIG']._serialized_end=2482
  _globals['_AUTOSCALINGCONFIG']._serialized_start=2485
  _globals['_AUTOSCALINGCONFIG']._serialized_end=2694
  _globals['_SCALINGMETRIC']._serialized_start=2697
  _globals['_SCALINGMETRIC']._serialized_end=2835
  _globals['_CONCURRENCY']._serialized_start=2837
  _globals['_CONCURRENCY']._serialized_end=2894
  _globals['_REQUESTRATE']._serialized_start=2896
  _globals['_REQUESTRATE']._serialized_end=2953
  _globals['_REPLICAS']._serialized_start=2955
  _globals['_REPLICAS']._serialized_end=3019
# @@protoc_insertion_point(module_scope)
